Masque of Judas Lisbon, Portugal February 21st 2009 12 players Teresa Neves Deck Name: Classic Giovanni Tap and Bleed Description: Classic design block denial bleed deck. From the times of Luis Duarte up until today, little changed. Completely ignored combat. Secret Passage, Secure Haven and a small cap can stop most of the attacks. Promise of 1528 is awesome in post KoT environment. Crypt (12 cards, min=12, max=27, avg=4.83) ------------------------------------------ 2x Gillespi Giovanni 7 DOM NEC POT aus Giovanni:2 2x Isabel Giovanni 5 DOM NEC pot Giovanni:2 2x Gloria Giovanni 4 DOM nec Giovanni:2 1x Andrea Giovanni 7 DOM NEC pot vic Giovanni:2 1x Rafaele Giovanni 6 NEC cel obf Giovanni:2 1x Le Dinh Tho 5 NEC aus dom Nagaraja:2 1x Lia Milliner 3 dom nec Giovanni:3 1x Rudolfo Giovanni 3 NEC Giovanni:2 1x Marciana Giovanni, Investigator 2 dom Giovanni:2 Library (90 cards) Master (20; 9 trifle) 1x Anarch Troublemaker 1x Dis Pater 2x Dreams of the Sphinx 4x Life in the City 1x Morgue Hunting Ground 5x Secret Passage 1x Secure Haven 5x Vessel Action (17) 9x Govern the Unaligned 5x Scouting Mission 3x Sudario Refraction Action Modifier (30) 2x Bonding 8x Call of the Hungry Dead 2x Command of the Beast 6x Conditioning 3x Leverage 4x Seduction 5x Sleeping Mind, The Action Modifier/Reaction (10) 4x Promise of 1528 6x Spectral Divination Reaction (13) 5x Deflection 3x On the Qui Vive 3x Redirection 2x Wake with Evening's Freshness